@@ -1,6 +1,7 @@
+#include <QDate>
+#include <QFrame>
 #include <QProcess>
 #include <QVBoxLayout>
-#include <QFrame>
 
 #include "aboutdialog.h"
 #include "settings.h"
@@ -21,11 +22,11 @@ AboutDialog::AboutDialog( QWidget *parent)
     tabs=new QTabWidget (this);
     credits=new AboutTextBrowser (parent);
 
-    credits->setHtml(
+    credits->setHtml( QString(
     "<center><img src=\""+iconPath+"vym-128x128.png\"></center>"
     "<h3><center>VYM - View Your Mind </h3>"
     "<p align=\"center\"> A tool to put the things you have got in your mind into a map.</p>"
-    "<p align=\"center\"> (c) by Uwe Drechsel (<a href=\"mailto:vym@InSilmaril.de\">vym@InSilmaril.de</a>)</p>"
+    "<p align=\"center\"> (c) 2004-%1 by Uwe Drechsel (<a href=\"mailto:vym@InSilmaril.de\">vym@InSilmaril.de</a>)</p>"
     "<p align=\"center\"> Version " +vymVersion+" - " +vymBuildDate+"</p>"
     "<p align=\"center\"> " +vymCodeName+"</p>"
     "<ul>"
@@ -55,7 +56,8 @@ AboutDialog::AboutDialog( QWidget *parent)
     "    <li>Spanish: <a href=\"http://ieee.udistrital.edu.co/aclibre\">"
     "                 ACLibre (Academia y Conocimiento Libre)</a> and David Amian</li>"
     "    <li>French: Philippe Caillaud and Claude </li>"
-    "    <li>Italian: Seyed Puria Nafisi Azizi </li>"
+    "    <li>Italian: Giovanni Sora, Seyed Puria Nafisi Azizi </li>"
+    "    <li>Interlingua: Giovanni Sora</li>"
     "    <li>Brasilian: Amadeu Júnior</li>"
     "    <li>Russian: Anton Olenev</li>"
     "    <li>Simplified Chinese: Moligaloo</li>"
@@ -79,26 +81,29 @@ AboutDialog::AboutDialog( QWidget *parent)
     "<li> Packaging"
     "</li>"
     "  <ul>"
+    "    <li>Scott Dillman and Patrick Spendrin: Recent windows patches</li>"
+    "    <li>Jon Ciesla: Sourceforge file releases</li>"
+    "    <li>Andrew Ng, Juha Ruotsalainen and Thomas Kriener: Older windows patches</li>"
     "    <li>Xavier Oswald, Christoph Thielecke and Steffen Joeris: Debian packaging</li>"
-    "    <li>Andrew Ng, Juha Ruotsalainen and Thomas Kriener: Windows</li>"
     "  </ul>"
     "<li> General"
     "  <ul>"
+    "    <li>CMake setup by Costantino Giuliodori and Patrick Spendrin</li>"
     "    <li>All the guys at Trolltech (now Nokia) for their Qt toolkit</li>"
     "    <li>All the guys at SUSE Linux for openSUSE Linux and support,"
     "        e.g. to get Linux running on PowerPC and also Macbooks</li>"
     "  </ul>"
     "</li>"
     "</ul>"
-    "</li>");
+    "</li>").arg( QDate::currentDate().year() ) );;
     credits->setFrameStyle( QFrame::Panel | QFrame::Plain );
     tabs->addTab (credits,"Credits");
 
     license=new AboutTextBrowser (parent);
-    license->setText (
+    license->setText ( QString(
     "<center>"
     "<h3>VYM - View Your Mind</h3>"
-    "<p>Copyright (C) 2004-2011  Uwe Drechsel</p>"  
+    "<p>Copyright (C) 2004-%1 Uwe Drechsel</p>"  
     "</center>"
 
     "<p>This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License version 2 as published by the Free Software Foundation.</p>"
@@ -204,9 +209,8 @@ AboutDialog::AboutDialog( QWidget *parent)
 
 "<p>  12. IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR REDISTRIBUTE THE PROGRAM AS PERMITTED ABOVE, BE LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE THE PROGRAM (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A FAILURE OF THE PROGRAM TO OPERATE WITH ANY OTHER PROGRAMS), EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.</p>"
 
-"<p align=\"center\">END OF TERMS AND CONDITIONS</p>"
-    
-    );
+"<p align=\"center\">END OF TERMS AND CONDITIONS</p>").arg( QDate::currentDate().year() ) );
+
     credits->setFrameStyle( QFrame::Panel | QFrame::Plain );
     tabs->addTab (license,"License");
 
