@@ -2,24 +2,23 @@
 #define FLOATIMAGEOBJ_H
 
 #include "floatobj.h"
-//Added by qt3to4:
 #include <QPixmap>
 
 class TreeItem;
-/*! \brief A pixmap which can be positioned freely as FlagObj  on the map.  */
+/*! \brief A pixmap which can be positioned freely on the map.  */
 
 
 /////////////////////////////////////////////////////////////////////////////
 class FloatImageObj:public FloatObj {
 public:
-    FloatImageObj (QGraphicsScene*,TreeItem *ti=NULL);
+    FloatImageObj (QGraphicsItem*,TreeItem *ti=NULL);
     ~FloatImageObj ();
-    virtual void init ();
     virtual void copy (FloatImageObj*);
     virtual void setZValue (const int&);
     virtual int z();
 
     virtual void load (const QImage &);
+    virtual void setParObj (QGraphicsItem*);
     virtual void setVisibility(bool);	    // set vis. for w
     virtual void move (double x,double y);
     virtual void move (QPointF);
