@@ -139,6 +139,8 @@ int main(int argc, char* argv[])
 
     // Reading and initializing options commandline options
     options.add ("batch", Option::Switch, "b", "batch");
+    options.add ("commands", Option::Switch, "c", "commands");
+    options.add ("commandslatex", Option::Switch, "cl", "commandslatex");
     options.add ("debug", Option::Switch, "d", "debug");
     options.add ("help", Option::Switch, "h", "help");
     options.add ("local", Option::Switch, "l", "local");
@@ -160,6 +162,7 @@ int main(int argc, char* argv[])
 	"Usage: vym [OPTION]... [FILE]... \n"
 	"Open FILEs with vym\n\n"
 	"-b           batch       batch mode: hide windows\n"
+	"-c           commands	  List all available commands\n"
 	"-d           debug       Show debugging output\n"
 	"-h           help        Show this help text\n"
 	"-l           local       Run with ressources in current directory\n"
@@ -173,17 +176,12 @@ int main(int argc, char* argv[])
 	"-v           version     Show vym version\n"
     );
 
-    taskModel = new TaskModel();
-
     if (options.parse())
     {
 	cout << endl << qPrintable( options.getHelpText())<<endl;
 	return 1;
     }
 
-    debug=options.isOn ("debug");
-    testmode=options.isOn ("testmode");
-
     if (options.isOn ("version"))
     {
 	cout << "VYM - View Your Mind (c) 2004-"<< QDate::currentDate().year()<<" Uwe Drechsel "  << endl
@@ -194,6 +192,11 @@ int main(int argc, char* argv[])
 	return 0;   
     }	    
     
+    taskModel = new TaskModel();
+
+    debug=options.isOn ("debug");
+    testmode=options.isOn ("testmode");
+
     // Register for DBUS
     if (debug) cout << "PID="<<getpid()<<endl;
     QString pidString=QString ("%1").arg(getpid());
@@ -308,6 +311,21 @@ int main(int argc, char* argv[])
 
     m.setWindowIcon (QPixmap (iconPath+"vym.png"));
     m.fileNew();
+
+    if (options.isOn ("commands"))
+    {
+	cout << "Available commands:\n";
+	cout << "==================:\n";
+	foreach (Command* c, modelCommands)
+	    cout << c->getDescription().toStdString() << endl;
+    }
+
+    if (options.isOn ("commandslatex"))
+    {
+	foreach (Command* c, modelCommands)
+	    cout << c->getDescriptionLaTeX().toStdString() << endl;
+    }
+
     if (options.isOn ("batch"))
 	m.hide();
     else	
