@@ -254,6 +254,14 @@ TreeItem *TreeItem::parent()
     return parentItem;
 }
 
+bool TreeItem::isChildOf (TreeItem *ti)
+{
+    if (this==rootItem) return false;
+    if (parentItem==ti) return true;
+    if (parentItem==rootItem) return false;
+    return parentItem->isChildOf (ti);
+}
+
 int TreeItem::childNum()
 {
     return parentItem->childItems.indexOf (this);
