@@ -4,10 +4,10 @@
 #include <QString>
 
 #define __VYM_NAME "VYM"
-#define __VYM_VERSION "2.2.4"
-#define __VYM_CODENAME "Codename: Production release"
-//#define __VYM_CODENAME "Codename: development version, not for production!"
-#define __VYM_BUILD_DATE "2012-07-04"
+#define __VYM_VERSION "2.3.0"
+//#define __VYM_CODENAME "Codename: Production release"
+#define __VYM_CODENAME "Codename: development version, not for production!"
+#define __VYM_BUILD_DATE "2012-07-06"
 #define __VYM_HOME "http://www.insilmaril.de/vym"
 
 bool checkVersion(const QString &);
